summaryrefslogtreecommitdiff
path: root/autogen.sh
diff options
context:
space:
mode:
Diffstat (limited to 'autogen.sh')
-rwxr-xr-xautogen.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/autogen.sh b/autogen.sh
index 7f08e9b..7bb241e 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -3,13 +3,13 @@ set -e
if test -n "$AUTOMAKE"; then
: # don't override an explicit user request
-elif automake-1.9 --version >/dev/null 2>/dev/null && \
- aclocal-1.9 --version >/dev/null 2>/dev/null; then
- # If we have automake-1.9, use it. This helps to ensure that our build
- # system doesn't accidentally grow automake-1.10 dependencies.
- AUTOMAKE=automake-1.9
+elif automake-1.11 --version >/dev/null 2>/dev/null && \
+ aclocal-1.11 --version >/dev/null 2>/dev/null; then
+ # If we have automake-1.11, use it. This helps to ensure that our build
+ # system doesn't accidentally grow other dependencies.
+ AUTOMAKE=automake-1.11
export AUTOMAKE
- ACLOCAL=aclocal-1.9
+ ACLOCAL=aclocal-1.11
export ACLOCAL
fi